"""
Version information for NetworkX, created during installation.

Do not add this file to the repository.

"""

import datetime

version = '1.9'
date = 'Wed Jun 25 12:02:42 2014'

# Was NetworkX built from a development version? If so, remember that the major
# and minor versions reference the "target" (rather than "current") release.
dev = False

# Format: (name, major, min, revision)
version_info = ('networkx', '1', '9', None)

# Format: a 'datetime.datetime' instance
date_info = datetime.datetime(2014, 6, 25, 12, 2, 42, 340629)

# Format: (vcs, vcs_tuple)
vcs_info = (None, (None, None))

